pub struct WebConfig {
pub canvas_id: Option<String>,
}Expand description
Web host configuration for browser platforms.
Fields
canvas_id: Option<String>An optional canvas element id to mount into before falling back to the default body append behavior.
Implementations